@@ -3,12 +3,12 @@
 #define LIST_TOKENS	"\t, \r\n"
 
 /*
-	Used to store TestHeaderYes, TestHeaderFloat, TestDNSBL
+	Used to store definitions for all tests defined in configuration file
 */
 struct testentry
 {
 	int match;			/* after testing, 1=test matched, 0=didn't */
-	int adds;			/* 1=this test adds to score, 0=subtracts */
+	float weight;			/* weight multiplier (positive or negative) */
 	char testname[MAXLINEBUF];	/* name of the test, shown in test results */
 	char param[MAXLINEBUF];		/* parameter, header field or DNSBL zone */
 	struct testentry* next;		/* pointer to next in chain */
